﻿
using System;
using System.Collections.Generic;
using System.Linq;
using Avalonia.Controls;
using KnigolubAvalonia.Data;
using KnigolubAvalonia.Models;
using KnigolubAvalonia.Views;
using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Infrastructure.Internal;
using ReactiveUI;

namespace KnigolubAvalonia.ViewModels;

public class MainWindowViewModel : ViewModelBase
{
#pragma warning disable CA1822 // Mark members as static
    public string Greeting => "Welcome to Provider!";
    /*
     * DataContext'ы для всех страниц.
     * Повзоляет реализовывать многостраничность с переносом данных
     * для каждой страниццы в отдельную ViewModel.
     */

    public User LoginUser { get => GlobalData.AuthUser; }

    private LoginVM loginDC = new LoginVM();
    public LoginVM LoginDC
    {
        get => loginDC;
        set => loginDC = value ?? throw new ArgumentNullException(nameof(value));
    }


    /// <summary>
    /// Контекст данных для страницы с информацией о провайдерах.
    /// </summary>
    private ProviderVM providerDC = new ProviderVM();
    public ProviderVM ProviderDc
    {
        get => providerDC;
        set => this.RaiseAndSetIfChanged(ref providerDC, value);
    }

    private AboutProviderVM aboutProviderDC = new AboutProviderVM();
    public AboutProviderVM AboutProviderDc
    {
        get => aboutProviderDC;
        set => aboutProviderDC = value ?? throw new ArgumentNullException(nameof(value));
    }

    private InvoicesVM invoicesDC = new InvoicesVM();
    public InvoicesVM InvoicesDC
    {
        get => invoicesDC;
        set => invoicesDC = value ?? throw new ArgumentNullException(nameof(value));
    }

    private AboutInvoiceViewModel aboutInvoiceDC;
    public AboutInvoiceViewModel AboutInvoiceDC
    {
        get => aboutInvoiceDC;
        set => aboutInvoiceDC = value ?? throw new ArgumentNullException(nameof(value));
    }

    /*
     * Поле, свойство и методы для переключения страниц
     * (т.е. смены UserControl, находящегося в ContextControl на главном окне).
     */
    private UserControl mainPage = new LoginPage();
    public UserControl MainCurrentPage
    {
        get => mainPage;
        set => this.RaiseAndSetIfChanged(ref mainPage, value);
    }

    private UserControl currentPage;
    public UserControl CurrentPage
    {
        get => currentPage;
        set => this.RaiseAndSetIfChanged(ref currentPage, value);
    }

    /// <summary>
    /// Свойство для определения роли администратора
    /// </summary>
    public string ItsAdmin => GlobalData.AuthUser.IdRoleNavigation.Name == "Администратор" ? "true" : "false";

    string showError = "false";
    public string ShowError { get => showError; set => this.RaiseAndSetIfChanged(ref showError, value); }

    public void AuthUser()
    {
        User user = GlobalData.DbConnection.Users.Include(x=>x.IdRoleNavigation).FirstOrDefault(x =>
         x.Username == LoginDC.EnteredUsername
         && x.Password == LoginDC.EnteredPassword);

        if (user != null)
        {
            GlobalData.AuthUser = user;
            MainCurrentPage = new MainPageTemplate();
            GoToProviderPage();
        }
        else ShowError = "true";

    }
    public void GoToLoginPage()
    {
        GlobalData.AuthUser = new();
        ShowError = "false";
        MainCurrentPage = new LoginPage();
    }

    public void GoToProviderPage()
    {
        CurrentPage = new ProviderPage();
        ProviderDc = new();
    }

    public void GoToInvoicesPage()
    {
        CurrentPage = new InvoicesPage();
        InvoicesDC = new();
    }
    public void GoToUserInfoPage()
    {
        CurrentPage = new UserInfoPage();
    }    
    public void GoToUserListPage()
    {
        CurrentPage = new UserListPage();
    }

    public void AddNewProvider()
    {
        aboutProviderDC = new AboutProviderVM();
        AboutProviderWindow window = new(aboutProviderDC);
        window.Show();
    }
    public void UpdateProvider(int idProvider)
    {
        Provider? curentProvider = GlobalData.DbConnection.Providers.Include(x=>x.Invoices).FirstOrDefault(x => x.Id == idProvider);
        if(curentProvider != null)
        {
            aboutProviderDC = new AboutProviderVM(curentProvider);
            AboutProviderWindow window = new(aboutProviderDC);
            window.Show();
            ProviderDc.Providers = GlobalData.DbConnection.Providers
                .Include(x => x.Invoices)
                .ToList();
        }
    }

    public void UpdateInvoices(int idInvoice)
    {
        aboutInvoiceDC = idInvoice == 0 ? new AboutInvoiceViewModel() : new AboutInvoiceViewModel(idInvoice);
        AboutInvoiceWindow window = new(aboutInvoiceDC);
        window.Show();
    }


#pragma warning restore CA1822 // Mark members as static
}